@@ -16,8 +16,8 @@ class Top_Keyword_Thread(threading.Thread):
         print ("===开启 %s 数据获取线程===" %(self.name))
         # 获取锁，用于线程同步
         threadLock.acquire()
-        get_top_keyword(self.args[0], self.args[1], self.args[2], self.args[3]).df_to_excel(self.args[4])
-        get_multiple_top_keyword(self.args[0], self.args[1], self.args[2], self.args[3], self.args[4])
+        Get_Top_Keyword(self.args[0], self.args[1], self.args[2], self.args[3]).df_to_excel(self.args[4])
+        Get_Multiple_Top_Keyword(self.args[0], self.args[1], self.args[2], self.args[3], self.args[4])
         # 释放锁，开启下一个线程
         threadLock.release()
 
